# tdameritrade
Python interface to TD Ameritrade Api


[![Build Status](https://travis-ci.org/timkpaine/tdameritrade.svg?branch=master)](https://travis-ci.org/timkpaine/tdameritrade)
[![Coverage](https://codecov.io/gh/timkpaine/tdameritrade/branch/master/graph/badge.svg)](https://codecov.io/gh/timkpaine/tdameritrade)
[![Waffle.io](https://badge.waffle.io/timkpaine/tdameritrade.png?label=ready&title=Ready)](https://waffle.io/timkpaine/tdameritrade?utm_source=badge)
[![BCH compliance](https://bettercodehub.com/edge/badge/timkpaine/tdameritrade?branch=master)](https://bettercodehub.com/)
[![License](https://img.shields.io/github/license/timkpaine/tdameritrade.svg)](https://pypi.python.org/pypi/tdameritrade/)
[![PyPI](https://img.shields.io/pypi/v/tdameritrade.svg)](https://pypi.python.org/pypi/tdameritrade/)
[![Docs](https://img.shields.io/readthedocs/tdameritrade.svg)](https://tdameritrade.readthedocs.io)


## Getting Started
[Read the docs!](http://tdameritrade.readthedocs.io/en/latest/index.html)


### Options Data
![](https://raw.githubusercontent.com/timkpaine/tdameritrade/master/docs/img/options.png)
